macro_rules! impl_styled_widget {
([$($gen:tt)*], $ty:ty) => { ... };
($ty:ty) => { ... };
}Expand description
Implements StyledWidget for a type that already has an inherent
show(self, ui: &mut Ui) -> Response method.
macro_rules! impl_styled_widget {
([$($gen:tt)*], $ty:ty) => { ... };
($ty:ty) => { ... };
}Implements StyledWidget for a type that already has an inherent
show(self, ui: &mut Ui) -> Response method.